Learn R Programming

WufooR (version 0.6.1)

form_entries: Return responses of your form

Description

If you have 5 submissions to your form, you'll have 5 elements (rows) in the return.

Usage

form_entries(wufoo_name = auth_name(NULL), formIdentifier = NULL, systemFields = "true", sortID = NULL, sortDirection = NULL, columnNames = FALSE, showRequestURL = FALSE, debugConnection = 0L, domain = "wufoo.com", pageStart = 0, pageSize = 25)

Arguments

wufoo_name
- User's Name. Default: auth_name
formIdentifier
- must be replaced with your form's URL or hash.
systemFields
- return system fields. Default: true
sortID
- sort on a single ID, as retrieved from the fields_info.
sortDirection
- choose to sort your entries ASC (lowest to highest) or DESC (highest to lowest).
columnNames
- a MUST: How should be column names be called. Either "Field1", "Field2" etc. or "First Name", "Last Name" (tries to make best guess). Default to the second option.
showRequestURL
- use only for DEBUG purposes
debugConnection
- samilar as above. Either "0L" (false; default) or "1L"
domain
- for thatever reason domain's ccTLD may change. With this param you can change default wufoo.com to another one such as wufoo.eu
pageStart
- the page number you'd like to start from. Defaults to 0.
pageSize
- the number of entries returned in your page. Defaults to 25; Max = 100.

Value

EntryId - This value is the unique identifier for your entry.DateCreated - The date that this entry was submitted.Created By - The person who created the entry. If submitted through a form, the value here will be public. If the submission originated in the Entry Manager this value will be the user name of the submitting user.DateUpdated - The date that this entry was edited through the Entry Manager. If the submission has never been updated, this value will be blank.UpdatedBy - The user name of the person who updated the entry in the Entry Manager will appear in this element.

See Also

http://help.wufoo.com/articles/en_US/SurveyMonkeyArticleType/The-Entries-GET-API

Examples

Run this code
form_entries(formIdentifier = "z5kqx7h1gtvg4g")
form_entries(formIdentifier = "z5kqx7h1gtvg4g", systemFields = "false", showRequestURL = TRUE)

Run the code above in your browser using DataLab