form_entries(wufoo_name = auth_name(NULL), formIdentifier = NULL,
systemFields = "true", sortID = NULL, sortDirection = NULL,
columnNames = FALSE, showRequestURL = FALSE, debugConnection = 0L,
domain = "wufoo.com")auth_namefields_info.wufoo.com to another one such as wufoo.euDateCreated - The date that this entry was submitted.
Created By - The person who created the entry. If submitted through a form, the value here will be public. If the submission originated in the Entry Manager this value will be the user name of the submitting user.
DateUpdated - The date that this entry was edited through the Entry Manager. If the submission has never been updated, this value will be blank.
UpdatedBy - The user name of the person who updated the entry in the Entry Manager will appear in this element.
form_entries(formIdentifier = "z5kqx7h1gtvg4g")
form_entries(formIdentifier = "z5kqx7h1gtvg4g", systemFields = "false", showRequestURL = TRUE)Run the code above in your browser using DataLab