EntryId - This value is the unique identifier for your entry.DateCreated - The date that this entry was submitted.
Created By - The person who created the entry. If submitted through a form, the value
here will be public. If the submission originated in the Entry Manager this value will be the
user name of the submitting user.
DateUpdated - The date that this entry was edited through the Entry Manager. If the
submission has never been updated, this value will be blank.
UpdatedBy - The user name of the person who updated the entry in the Entry Manager will
appear in this element.