form_info: Return details about the forms you have permission to access.
Description
This API can be used to create a list of all forms belonging to a user and
dynamically generate a form embed snippet to use in your application.Usage
form_info(wufoo_name = auth_name(NULL), formIdentifier = NULL,
includeTodayCount = "false", showRequestURL = FALSE,
debugConnection = 0L, domain = "wufoo.com")
Arguments
formIdentifier
- this will give you information about just one form. The call without
the "formIdentifier" will return all forms.
includeTodayCount
- Will give you today's entry count for the form.
showRequestURL
- use only for DEBUG purposes
debugConnection
- samilar as above. Either "0L" (false; default) or "1L"
domain
- for thatever reason domain's ccTLD may change. With this param you can change
default wufoo.com to another one such as wufoo.eu
Value
- http://help.wufoo.com/articles/en_US/SurveyMonkeyArticleType/The-Forms-API