reports_info(wufoo_name = auth_name(NULL), domain = "wufoo.com",
reportName = NULL, showRequestURL = FALSE, debugConnection = 0L)auth_namewufoo.com to another one such as wufoo.euIsPublic - Indicates whether or not the report is accessible through the Url by the general public. This value is binary (1 = true, 0 = false).
Url - This is the URL for your form. Beware using the URL for API or linking purposes because it changes with the report title.
Description - Your description of the report.
DateCreated - A timestamp of when the report was created.
DateUpdated - A timestamp of when the report was lasted edited in the Wufoo Report Builder.
Hash - An unchanging hashed value unique to this report on this user's account.
reports_info(showRequestURL = TRUE)
reports_info(reportName = "untitled-report")Run the code above in your browser using DataLab