Learn R Programming

WufooR (version 0.5.7)

reports_info: Return details about the reports you have permission to view.

Description

Return details about the reports you have permission to view.

Usage

reports_info(wufoo_name = auth_name(NULL), reportName = NULL,
  showRequestURL = FALSE)

Arguments

wufoo_name
- User's Name. Default: auth_name
reportName
- the name (not the hash!) of the specific report
showRequestURL
- use only for DEBUG purposes

Value

  • Name - This is the friendly name you chose when creating this form.

    IsPublic - Indicates whether or not the report is accessible through the Url by the general public. This value is binary (1 = true, 0 = false).

    Url - This is the URL for your form. Beware using the URL for API or linking purposes because it changes with the report title.

    Description - Your description of the report.

    DateCreated - A timestamp of when the report was created.

    DateUpdated - A timestamp of when the report was lasted edited in the Wufoo Report Builder.

    Hash - An unchanging hashed value unique to this report on this user's account.

Examples

Run this code
reports_info(showRequestURL = TRUE)
reports_info(reportName = "untitled-report")

Run the code above in your browser using DataLab